@@ -1,5 +1,4 @@
-#' SciViews - Main package
-#'
+#' @details
 #' The SciViews package provides various functions to install the SciViews::R
 #' dialect. It also provides additional utilites besides base, recommended and
 #' tidyverse.
@@ -8,11 +7,15 @@
 #'
 #' TODO...
 #'
-#' @docType package
-#' @name SciViews-package
+#' @keywords internal
+"_PACKAGE"
 #'
 #' @import stats
 #' @import graphics
 #' @importFrom grDevices colorRampPalette chull hsv rainbow
 #' @importFrom ellipse ellipse plotcorr
+# The following block is used by usethis to automatically manage
+# roxygen namespace tags. Modify with care!
+## usethis namespace: start
+## usethis namespace: end
 NULL
